@@ -21,7 +21,6 @@
 #include "mailtransport_debug.h"
 #include <KPasswordDialog>
 
-#include <KSMTP/Session>
 #include <KSMTP/LoginJob>
 #include <KSMTP/SendJob>
 
@@ -37,11 +36,7 @@ using namespace MailTransport;
 class SessionPool
 {
 public:
-    SessionPool() : ref(0)
-    {
-    }
-
-    int ref;
+    int ref = 0;
     QHash<int, KSmtp::Session *> sessions;
 
     void removeSession(KSmtp::Session *session)
@@ -76,7 +71,7 @@ public:
 
     void doLogin();
 
-    SmtpJob *q;
+    SmtpJob *const q;
     KSmtp::Session *session = nullptr;
     KSmtp::SessionUiProxy::Ptr uiProxy;
     enum State {
@@ -190,22 +185,22 @@ void SmtpJob::startPasswordRetrieval(bool forceRefresh)
             GOOGLE_API_KEY, transport()->userName(), { KGAPI2::Account::mailScopeUrl() });
         connect(promise, &KGAPI2::AccountPromise::finished,
                 this, [forceRefresh, this](KGAPI2::AccountPromise *promise) {
-                    if (promise->account()) {
-                        if (forceRefresh) {
-                            promise = KGAPI2::AccountManager::instance()->refreshTokens(
-                                GOOGLE_API_KEY, GOOGLE_API_SECRET, transport()->userName());
-                        } else {
-                            onTokenRequestFinished(promise);
-                            return;
-                        }
-                    } else {
-                        promise = KGAPI2::AccountManager::instance()->getAccount(
-                            GOOGLE_API_KEY, GOOGLE_API_SECRET, transport()->userName(),
-                            { KGAPI2::Account::mailScopeUrl() });
-                    }
-                    connect(promise, &KGAPI2::AccountPromise::finished,
-                            this, &SmtpJob::onTokenRequestFinished);
-                });
+            if (promise->account()) {
+                if (forceRefresh) {
+                    promise = KGAPI2::AccountManager::instance()->refreshTokens(
+                        GOOGLE_API_KEY, GOOGLE_API_SECRET, transport()->userName());
+                } else {
+                    onTokenRequestFinished(promise);
+                    return;
+                }
+            } else {
+                promise = KGAPI2::AccountManager::instance()->getAccount(
+                    GOOGLE_API_KEY, GOOGLE_API_SECRET, transport()->userName(),
+                    { KGAPI2::Account::mailScopeUrl() });
+            }
+            connect(promise, &KGAPI2::AccountPromise::finished,
+                    this, &SmtpJob::onTokenRequestFinished);
+        });
     } else {
         startLoginJob();
     }
@@ -228,7 +223,6 @@ void SmtpJob::onTokenRequestFinished(KGAPI2::AccountPromise *promise)
     startLoginJob();
 }
 
-
 void SmtpJob::startLoginJob()
 {
     if (!transport()->requiresAuthentication()) {
@@ -242,9 +236,9 @@ void SmtpJob::startLoginJob()
         && transport()->authenticationType() != Transport::EnumAuthenticationType::GSSAPI) {
         QPointer<KPasswordDialog> dlg
             = new KPasswordDialog(
-            nullptr,
-            KPasswordDialog::ShowUsernameLine
-            |KPasswordDialog::ShowKeepPassword);
+                  nullptr,
+                  KPasswordDialog::ShowUsernameLine
+                  |KPasswordDialog::ShowKeepPassword);
         dlg->setAttribute(Qt::WA_DeleteOnClose, true);
         dlg->setPrompt(i18n("You need to supply a username and a password "
                             "to use this SMTP server."));
@@ -375,7 +369,7 @@ void SmtpJob::slotResult(KJob *job)
         return;
     }
 
-    if (qobject_cast<KSmtp::LoginJob*>(job)) {
+    if (qobject_cast<KSmtp::LoginJob *>(job)) {
         if (job->error() == KSmtp::LoginJob::TokenExpired) {
             startPasswordRetrieval(/*force refresh */ true);
             return;
